pub struct Worlds {
pub map: FxHashMap<WorldName, Weak<RwLock<World>>>,
}Expand description
A container of World instances.
Worlds are stored as a Weak pointer here, so if no clients are using a
world then it will be forgotten.
Fields
map: FxHashMap<WorldName, Weak<RwLock<World>>>Implementations
Sourceimpl Worlds
impl Worlds
pub fn new() -> Self
Sourcepub fn get(&self, name: &WorldName) -> Option<Arc<RwLock<World>>>
pub fn get(&self, name: &WorldName) -> Option<Arc<RwLock<World>>>
Get a world instance from the container.
Returns None if none of the clients are in the requested world.
Sourcepub fn get_or_insert(
&mut self,
name: WorldName,
height: u32,
min_y: i32,
default_registries: &RegistryHolder,
) -> Arc<RwLock<World>>
pub fn get_or_insert( &mut self, name: WorldName, height: u32, min_y: i32, default_registries: &RegistryHolder, ) -> Arc<RwLock<World>>
Add an empty world to the container (unless it already exists) and returns a strong reference to the world.